@@ -10,20 +10,16 @@
 
 std::unique_ptr<KDecoration2::DecoratedClientPrivate> MockBridge::createClient(KDecoration2::DecoratedClient *client, KDecoration2::Decoration *decoration)
 {
-    auto ptr = std::unique_ptr<MockClient>(new MockClient(client, decoration));
+    auto ptr = std::make_unique<MockClient>(client, decoration);
     m_lastCreatedClient = ptr.get();
-    return std::move(ptr);
+    return ptr;
 }
 
 std::unique_ptr<KDecoration2::DecorationSettingsPrivate> MockBridge::settings(KDecoration2::DecorationSettings *parent)
 {
-    auto ptr = std::unique_ptr<MockSettings>(new MockSettings(parent));
+    auto ptr = std::make_unique<MockSettings>(parent);
     m_lastCreatedSettings = ptr.get();
-    return std::move(ptr);
+    return ptr;
 }
 
-void MockBridge::update(KDecoration2::Decoration *decoration, const QRect &geometry)
-{
-    Q_UNUSED(decoration)
-    Q_UNUSED(geometry)
-}
+#include "moc_mockbridge.cpp"
